<?php

namespace App\Http\Controllers\Auth;

use App\Http\Controllers\Controller;
use App\Providers\RouteServiceProvider;
use App\Models\User;
use App\Models\RegisterUser;
use App\Models\Otp;
use App\Models\Transcation;
use App\Models\Setting;
use Illuminate\Foundation\Auth\RegistersUsers;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Validator;
use Illuminate\Http\Request;
use Illuminate\Support\Str;
use Session,Response;

class RegisterController extends Controller
{
    /*
    |--------------------------------------------------------------------------
    | Register Controller
    |--------------------------------------------------------------------------
    |
    | This controller handles the registration of new users as well as their
    | validation and creation. By default this controller uses a trait to
    | provide this functionality without requiring any additional code.
    |
    */

    use RegistersUsers;

    /**
     * Where to redirect users after registration.
     *
     * @var string
     */
    protected $redirectTo = RouteServiceProvider::HOME;

    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        $this->middleware('guest');
    }

    /**
     * Get a validator for an incoming registration request.
     *
     * @param  array  $data
     * @return \Illuminate\Contracts\Validation\Validator
     */
    protected function validator(array $data)
    {
        return Validator::make($data, [
            'name' => ['required', 'string', 'max:255'],
            'email' => ['required', 'string', 'email', 'max:255', 'unique:users'],
            'password' => ['required', 'string', 'min:8', 'confirmed'],
        ]);
    }

    /**
     * Create a new user instance after a valid registration.
     *
     * @param  array  $data
     * @return \App\Models\User
     */
    protected function create(array $data)
    {
        return User::create([
            'name' => $data['name'],
            'email' => $data['email'],
            'password' => Hash::make($data['password']),
        ]);
    }
    public function Register(Request $request)
    {
        $this->validate($request, [
            'name' => 'required',
            'email' => 'required|unique:users',
            'phone_no' => 'required',
            'password' => 'required',
            'designation' => 'required',
            'image_upload' => 'required',
           
            
        ]);

        $user = new User;
        $user->name=Str::upper($request->name);
        $user->email = $request->email;
        $user->phone_no = $request->phone_no;
        $user->status = 1;
        $user->password = bcrypt($request->password);
        $user->assignRole('member');
        $user->unique_id=uniqid();
        $user->save();

        session()->flash('success_msg', 'User has been created successfully');
        return redirect()->route('login');
    }

    public function storeregister(Request $request){
        // dd($request->all());
        $request->validate([
            'name' => 'required',
            'phone' => 'required|unique:users',
            'email' => 'required',
            'referral_code' => 'required',
          
        ]);
        $registeruser = new RegisterUser;
        $registeruser->name = $request->name;
        $registeruser->phone = $request->phone;
        $registeruser->email = $request->email;
        $registeruser->referral_code = $request->referral_code;
        $registeruser->status = "1";
        $registeruser->unique_id = uniqid();
        $registeruser->save();

        session()->flash('success_msg', 'Add amount request has been submited Successfully');
        return redirect()->route('wallet');
    }

    public function register_store(Request $request){
        $request->validate([
            'name' => 'required',
            'phone' => 'required|unique:users',
            'email' => 'required',
          
        ]);
        // $this->validator($request->all())->validate();
      session()->put('register_data', $request->all());
        $code = rand(1111, 9999);
               Session::put('Otp', $code);
               $otp = new Otp;
               $otp->otp =  $code;
               $otp->status = 1;
               $otp->uniqid_id = uniqid();
               $otp->phone = $request->phone;
               $otp->save();
               return redirect()->route('regotp');
   }
 
public function regotp(){
    if(session()->get('Otp') != null){
    return view('auth.regotp');
    }else{
        return redirect('register');
    }
}

public function otp_storereg(Request $request){
    $data = Session::get('register_data');
  
  
    $code = '';
    foreach($request->otp as $r){
        $code .= $r;
    }

    $phone=$data['phone'];
    $length = Str::length($code);
    $getdata = Otp::where('status', 1)->where('phone', $phone)->orderBy('id', 'desc')->first();
    if(is_null($getdata)){
     
        return redirect()->back()->with('error_msg', 'invalid otp');
        }else{
            $user=User::where('referral_code_generate',$data['referral_code'])->count();
              $userid=User::where('referral_code_generate',$data['referral_code'])->value('id');
            if($getdata->otp == $code){
                $registeruser = new RegisterUser;
                 $registeruser->name = $data['name'];
            $registeruser->email = $data['email'];
            $registeruser->phone = '91'.$data['phone'];
            if(isset($data['referral_code'])){
                if($user!="0")
                    {
                        $registeruser->referral_code = $userid;
                    }
                else
                    {
                        $registeruser->referral_code = "";
                    }
            }
           

            
            $registeruser->referral_code_generate = uniqid();
            $registeruser->status = '1';
            $registeruser->unique_id =  uniqid();
            $registeruser->save();

            $user_detail = new User;
            $user_detail->registration_id=$registeruser->id;
            $user_detail->name=$registeruser->name;
            $user_detail->email=$registeruser->email;
            $user_detail->phone=$registeruser->phone;
            $user_detail->password=bcrypt('123456');
            $user_detail->referral_code=$registeruser->referral_code;
            $user_detail->referral_code_generate=$registeruser->referral_code_generate;
            $user_detail->status="1";
            $user_detail->unique_id=$registeruser->unique_id;
            $user_detail->assignRole('user');
            $user_detail->save();
            
              if(isset($data['referral_code'])){
                
                  $amount=Setting::where('_key','refral_bouns')->value('_value');
         
                $transcation = new Transcation;
                $transcation->payment_type = 'refral_bouns';
                $transcation->type = 'cr';
                $transcation->user_id =$userid;
                $transcation->amount = $amount;
                $transcation->remaining_amount = User::where('id',$userid)->value('wallet') + $amount;
                $transcation->transcation_status = "1";
                $transcation->unique_id = uniqid();
                $transcation->save();
                $user = User::findorFail($userid);
                $user->wallet += $amount;
                $user->save();
            }
            
            
            
                  $bonus=Setting::where('_key','bouns')->value('_value');
         
                $transcation = new Transcation;
                $transcation->payment_type = 'Registration Bouns';
                $transcation->type = 'cr';
                $transcation->user_id =$user_detail->id;
                $transcation->amount = $bonus;
                $transcation->remaining_amount = User::where('id',$user_detail->id)->value('wallet') + $bonus;
                $transcation->transcation_status = "1";
                $transcation->unique_id = uniqid();
                $transcation->save();
                $userbonus = User::findorFail($user_detail->id);
                $userbonus->wallet += $bonus;
                $userbonus->save();
                
            
            session()->forget('Otp');
            session()->forget('register_data');
            return redirect("login")->with('success_msg', 'Registered Successfully');
          
            }else{
                return redirect()->back()->with('error_msg', 'invalid otp');
            }
        }

}

public function resetotp(Request $request){
    $data = Session::get('register_data');
        $code = rand(1111, 9999);
    session()->forget('Otp');
          Session::put('Otp', $code);
          $otp = new Otp;
          $otp->otp =  $code;
          $otp->status = 1;
          $otp->uniqid_id = uniqid();
          $otp->phone = $data['phone'];
          $otp->save();
      return back();
}

}