<?php

namespace App\Http\Controllers\admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\Game;
use App\Models\GameType;
use App\Models\Notification;
class GameController extends Controller
{


public function index(){
    $items = Game::where('status', "1")->orderBy('id','desc')->get();
  return view('admin.game.index', compact('items'));
}

public function create(){
  return view('admin.game.create');
}

public function store(Request $request){
   $request->validate([
    'type'=>'required',
    'start_time'=>'required',
    'end_time'=>'required',
    'result_time'=>'required',
    'multiply'=>'required',
]);

$type = GameType::findorFail($request->type);
$game = new Game;
$game->name = $type->type;
$game->gametype_id = $type->id;
$game->start_time = date('d-m-Y H:i',strtotime($request->start_time));
$game->end_time = date('d-m-Y H:i',strtotime($request->end_time));
$game->result_time = date('d-m-Y H:i',strtotime($request->result_time));
$game->unique_id = uniqid();
$game->image = $type->image;
$game->multiply = $request->multiply;
$game->save();

$notification = new Notification;
    $notification->type = 'game_start';
    $notification->type_id = $game->id;
    $notification->user_type = 'all users';
    $notification->message = $game->name .' game start go now and play game';
    $notification->deliver_date = date('Y-m-d H:i',strtotime($request->start_time));
    $notification->unique_id = uniqid();
    $notification->save();

$notification1 = new Notification;
    $notification1->type = 'game_end';
    $notification1->type_id = $game->id;
    $notification1->user_type = 'all users';
    $notification1->message = $game->name .' game end';
    $notification1->deliver_date = date('Y-m-d H:i',strtotime($request->end_time));
    $notification1->unique_id = uniqid();
    $notification1->save();
session()->flash('success_msg', 'game has been created Successfully');
return redirect()->route('game.index');
}


function edit($id) {
    $game = Game::where('unique_id',$id)->first();
    if(is_null($game)){
        session()->flash('error_msg', 'No Data Found!');
        return back();
      }
    return view('admin.game.edit', compact('game'));
}



public function update(Request $request, $id){
   $request->validate([
    'type'=>'required',
    'start_time'=>'required',
    'end_time'=>'required',
    'result_time'=>'required',
    'multiply'=>'required',
]);


$game = Game::where('unique_id',$id)->first();
if(is_null($game)){
        session()->flash('error_msg', 'No Data Found!');
        return back()->withInput($request->all());
      }
      $type = GameType::findorFail($request->type);
$game->name = $type->type;
$game->gametype_id = $type->id;
$game->start_time = date('d-m-Y H:i',strtotime($request->start_time));
$game->end_time = date('d-m-Y H:i',strtotime($request->end_time));
$game->result_time = date('d-m-Y H:i',strtotime($request->result_time));
$game->image = $type->image;
$game->multiply = $request->multiply;
// if ($request->hasFile('image')) {
//   $image = $request->file('image');
//   $filename = time().'-'.$image->getClientOriginalName();
//   $destinationPath = public_path('uploads/game');
//   $image->move($destinationPath, $filename);
//   $game->image = "uploads/game/" . $filename;
// }
$game->save();

$notification = Notification::where('type_id',$game->id)->where('type','game_start')->first();
    if($notification){
    $notification->message = $game->name .' game start go now and play game';
    $notification->deliver_date = date('Y-m-d H:i',strtotime($request->start_time));
    $notification->save();
    }
$notification1 = Notification::where('type_id',$game->id)->where('type','game_end')->first();
if($notification1){
    $notification1->message = $game->name .' game end';
    $notification1->deliver_date = date('Y-m-d H:i',strtotime($request->end_time));
    $notification1->save();
}
session()->flash('success_msg', 'game has been updated Successfully');
return redirect()->route('game.index');
}

public function destroy($id){
    $game = game::where('unique_id',$id)->first();
    if(is_null($game)){
        session()->flash('error_msg', 'No Data Found!');
        return back();
      }
      $game->status = "0";
      $game->save();
      
           $notification = Notification::where('type_id',$game->id)->where('type','game_start')->first();
    if($notification){
    $notification->status = '0';
    $notification->save();
    }
$notification1 = Notification::where('type_id',$game->id)->where('type','game_end')->first();
if($notification1){
    $notification1->message = '0';
    $notification1->save();
}


      session()->flash('success_msg', 'game has been deleted Successfully');
      return redirect()->route('game.index');
}
}
